==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/libs/kotext/KoFindStrategy.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOFINDSTRATEGY_H
#define KOFINDSTRATEGY_H

#include "KoFindStrategyBase.h"

class QWidget;

/**
 * Stratagy used for implementing find
 */
class KoFindStrategy : public KoFindStrategyBase
{
public:
    explicit KoFindStrategy(QWidget *parent);
    virtual ~KoFindStrategy();

    /// reimplemented
    KFindDialog *dialog();

    /// reimplemented
    virtual void reset();

    /// reimplemented
    virtual void displayFinalDialog();

    /// reimplemented
    virtual bool foundMatch(QTextCursor &cursor, FindDirection *findDirection);

private:
    KFindDialog *m_dialog;
    int m_matches;
};

#endif /* KOFINDSTRATEGY_H */

==> calligra-2.9.11.tar.xz: calligra-2.9.11/libs/kotext/KoFindStrategy.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOFINDSTRATEGY_H
#define KOFINDSTRATEGY_H

#include "KoFindStrategyBase.h"

class QWidget;

/**
 * Stratagy used for implementing find
 */
class KoFindStrategy : public KoFindStrategyBase
{
public:
    explicit KoFindStrategy(QWidget *parent);
    virtual ~KoFindStrategy();

    /// reimplemented
    KFindDialog *dialog() const;

    /// reimplemented
    virtual void reset();

    /// reimplemented
    virtual void displayFinalDialog();

    /// reimplemented
    virtual bool foundMatch(QTextCursor &cursor, FindDirection *findDirection);

private:
    KFindDialog *m_dialog;
    int m_matches;
};

#endif /* KOFINDSTRATEGY_H */
